/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of Sales **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/Sales'] = ({
""
: "Project-Id-Version: Tine 2.0 - Sales\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2008-07-29 21:14+0100\nLast-Translator: Cornelius Weiss <c.weiss@metaways.de>\nLanguage-Team: Tine 2.0 Translators\nLanguage: \nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nX-Poedit-Language: en\nX-Poedit-Country: GB\nX-Poedit-SourceCharset: utf-8\nPlural-Forms: nplurals=2; plural=n != 1;\n"

, "Either postalcode or postbox is required!"
: "Either postalcode or postbox is required!"

, "Copy Supplier"
: "Copy Supplier"

, "Add New Supplier"
: "Add New Supplier"

, "Edit Supplier \"{0}\""
: "Edit Supplier \"{0}\""

, "Copy address to the clipboard"
: "Copy address to the clipboard"

, "Supplier, Suppliers"
: [
  "Supplier"
 ,"Suppliers"

]
, "Core Data"
: "Core Data"

, "Supplier Number"
: "Supplier Number"

, "Name"
: "Name"

, "Contact Person (external)"
: "Contact Person (external)"

, "Contact Person (internal)"
: "Contact Person (internal)"

, "Accounting"
: "Accounting"

, "VAT ID"
: "VAT ID"

, "Credit Term (days)"
: "Credit Term (days)"

, "Currency"
: "Currency"

, "Currency Translation Rate"
: "Currency Translation Rate"

, "IBAN"
: "IBAN"

, "BIC"
: "BIC"

, "Postal Address"
: "Postal Address"

, "Street"
: "Street"

, "Postbox"
: "Postbox"

, "Postalcode"
: "Postalcode"

, "Locality"
: "Locality"

, "Region"
: "Region"

, "Country"
: "Country"

, "Prefix"
: "Prefix"

, "Additional Prefix"
: "Additional Prefix"

, "Miscellaneous"
: "Miscellaneous"

, "Web"
: "Web"

, "Description"
: "Description"

, "Enter description"
: "Enter description"

, "total"
: "total"

, "inclusive"
: "inclusive"

, "exceeding"
: "exceeding"

, "Create timesheet"
: "Create timesheet"

, "Create Reversal Invoice"
: "Create Reversal Invoice"

, "Copy Invoice"
: "Copy Invoice"

, "Add New Invoice"
: "Add New Invoice"

, "Edit Invoice \"{0}\""
: "Edit Invoice \"{0}\""

, "Positions ({0})"
: "Positions ({0})"

, "No customer assigned"
: "No customer assigned"

, "The selected contract doesn't have a customer assigned, yet. Add a customer to the contract with the contract edit dialog."
: "The selected contract doesn't have a customer assigned, yet. Add a customer to the contract with the contract edit dialog."

, "No cost center assigned"
: "No cost center assigned"

, "The selected contract doesn't have a cost center assigned, yet. Add a cost center to the contract with the contract edit dialog."
: "The selected contract doesn't have a cost center assigned, yet. Add a cost center to the contract with the contract edit dialog."

, "Price Net"
: "Price Net"

, "Taxes (VAT)"
: "Taxes (VAT)"

, "Price Gross"
: "Price Gross"

, "Sales Tax (percent)"
: "Sales Tax (percent)"

, "Inventory Change"
: "Inventory Change"

, "Invoice, Invoices"
: [
  "Invoice"
 ,"Invoices"

]
, "Invoice Number"
: "Invoice Number"

, "automatically set..."
: "automatically set..."

, "Date"
: "Date"

, "Type"
: "Type"

, "Contract, Contracts"
: [
  "Contract"
 ,"Contracts"

]
, "Customer, Customers"
: [
  "Customer"
 ,"Customers"

]
, "Billing Address"
: "Billing Address"

, "Credit Term"
: "Credit Term"

, "Cleared"
: "Cleared"

, "Interval Begins"
: "Interval Begins"

, "Interval Ends"
: "Interval Ends"

, "Select invoice"
: "Select invoice"

, "Total Price"
: "Total Price"

, "Cancel"
: "Cancel"

, "OK"
: "OK"

, "Loading..."
: "Loading..."

, "Euro (€)"
: "Euro (€)"

, "Order Confirmation, Order Confirmations"
: [
  "Order Confirmation"
 ,"Order Confirmations"

]
, "without order confirmation"
: "without order confirmation"

, "Number"
: "Number"

, "Title"
: "Title"

, "Billing Addresses"
: "Billing Addresses"

, "Delivery Address"
: "Delivery Address"

, "Delivery Addresses"
: "Delivery Addresses"

, "Edit {0} \"{1}\""
: "Edit {0} \"{1}\""

, "Add New Billing Address"
: "Add New Billing Address"

, "Add New Delivery Address"
: "Add New Delivery Address"

, "Apply postal address"
: "Apply postal address"

, "Number Debit"
: "Number Debit"

, "Address, Addresss"
: [
  "Address"
 ,"Addresss"

]
, "without customer"
: "without customer"

, "Copy Purchase Invoice"
: "Copy Purchase Invoice"

, "Add New Purchase Invoice"
: "Add New Purchase Invoice"

, "Edit Purchase Invoice \"{0}\""
: "Edit Purchase Invoice \"{0}\""

, "Date of invoice"
: "Date of invoice"

, "Due in"
: "Due in"

, "Due date"
: "Due date"

, "Additional Price Gross"
: "Additional Price Gross"

, "Discount (%)"
: "Discount (%)"

, "Purchase Invoice, Purchase Invoices"
: [
  "Purchase Invoice"
 ,"Purchase Invoices"

]
, "Overdue date"
: "Overdue date"

, "Discount until"
: "Discount until"

, "Dun date"
: "Dun date"

, "Payed at"
: "Payed at"

, "Method of payment"
: "Method of payment"

, "Approver"
: "Approver"

, "Lead Cost Center"
: "Lead Cost Center"

, "Add New Offer"
: "Add New Offer"

, "Clipboard"
: "Clipboard"

, "Product, Products"
: [
  "Product"
 ,"Products"

]
, "Quantity"
: "Quantity"

, "Interval"
: "Interval"

, "Billing Point"
: "Billing Point"

, "begin"
: "begin"

, "end"
: "end"

, "Start Date"
: "Start Date"

, "End Date"
: "End Date"

, "Attributes"
: "Attributes"

, "Last Autobill"
: "Last Autobill"

, "Creation Time"
: "Creation Time"

, "Created By"
: "Created By"

, "Last Modified Time"
: "Last Modified Time"

, "Last Modified By"
: "Last Modified By"

, "Edit Attributes"
: "Edit Attributes"

, "Attribute"
: "Attribute"

, "Value"
: "Value"

, "Add a New Value..."
: "Add a New Value..."

, "without contract"
: "without contract"

, "Add New Order Confirmation"
: "Add New Order Confirmation"

, "Offer, Offers"
: [
  "Offer"
 ,"Offers"

]
, "Add New Product"
: "Add New Product"

, "Product Number"
: "Product Number"

, "GTIN"
: "GTIN"

, "Category"
: "Category"

, "Manufacturer"
: "Manufacturer"

, "Purchaseprice"
: "Purchaseprice"

, "Salesprice"
: "Salesprice"

, "Lifespan start"
: "Lifespan start"

, "Lifespan end"
: "Lifespan end"

, "Enter description..."
: "Enter description..."

, "Accountable"
: "Accountable"

, "Selected  {0}"
: "Selected  {0}"

, "Select customer"
: "Select customer"

, "Customer Number"
: "Customer Number"

, "Products"
: "Products"

, "Rebilling Invoice..."
: "Rebilling Invoice..."

, "Rebill Invoice"
: "Rebill Invoice"

, "Merge Invoices"
: "Merge Invoices"

, "Select supplier"
: "Select supplier"

, "Add New Cost Center"
: "Add New Cost Center"

, "Remark"
: "Remark"

, "without supplier"
: "without supplier"

, "Add New Division"
: "Add New Division"

, "Bill Contract"
: "Bill Contract"

, "Billing Contract..."
: "Billing Contract..."

, "Bill Contract \"{0} - {1}\""
: "Bill Contract \"{0} - {1}\""

, "Select the date to generate the bill for"
: "Select the date to generate the bill for"

, "Either street or postbox is required!"
: "Either street or postbox is required!"

, "Copy Customer"
: "Copy Customer"

, "Add New Customer"
: "Add New Customer"

, "Edit Customer \"{0}\""
: "Edit Customer \"{0}\""

, "Name shorthand"
: "Name shorthand"

, "Set as accountable"
: "Set as accountable"

, "Choose product for accountable"
: "Choose product for accountable"

, "Please use a decimal number here!"
: "Please use a decimal number here!"

, "Positions"
: "Positions"

, "Ok"
: "Ok"

, "Export Records from these Positions"
: "Export Records from these Positions"

, "without approver"
: "without approver"

, "Auto Invoice Contract Interval"
: "Auto Invoice Contract Interval"

, "Sets the biggest interval, contracts will be billed."
: "Sets the biggest interval, contracts will be billed."

, "Ignore Billables Before Date"
: "Ignore Billables Before Date"

, "Sets the date billables will be ignored before."
: "Sets the date billables will be ignored before."

, "Contract Number Creation"
: "Contract Number Creation"

, "Should the contract number be set manually or be auto-created?"
: "Should the contract number be set manually or be auto-created?"

, "automatically"
: "automatically"

, "manually"
: "manually"

, "Contract Number Validation"
: "Contract Number Validation"

, "The Number can be validated as text or number."
: "The Number can be validated as text or number."

, "Text"
: "Text"

, "Own Currency"
: "Own Currency"

, "The currency defined here is used as default currency in the customerd edit dialog."
: "The currency defined here is used as default currency in the customerd edit dialog."

, "Invoice Type"
: "Invoice Type"

, "Possible Invoice Types."
: "Possible Invoice Types."

, "Reversal"
: "Reversal"

, "Credit"
: "Credit"

, "Product Category"
: "Product Category"

, "Possible Product Categories."
: "Possible Product Categories."

, "Default"
: "Default"

, "Product Number Creation"
: "Product Number Creation"

, "Should the product number be set manually or be auto-created?"
: "Should the product number be set manually or be auto-created?"

, "Product Number Validation"
: "Product Number Validation"

, "Product Number Prefix"
: "Product Number Prefix"

, "The prefix of the product number."
: "The prefix of the product number."

, "Product Number Zero Fill"
: "Product Number Zero Fill"

, "Fill the number with leading zero"
: "Fill the number with leading zero"

, "Payment Method"
: "Payment Method"

, "Possible Payment Methods."
: "Possible Payment Methods."

, "Bank transfer"
: "Bank transfer"

, "Direct debit"
: "Direct debit"

, "Cancellation"
: "Cancellation"

, "Credit card"
: "Credit card"

, "EC card"
: "EC card"

, "Paypal"
: "Paypal"

, "Assets"
: "Assets"

, "Invoice Cleared"
: "Invoice Cleared"

, "Possible Invoice Cleared States."
: "Possible Invoice Cleared States."

, "to clear"
: "to clear"

, "cleared"
: "cleared"

, "Enabled Features"
: "Enabled Features"

, "Enabled Features in Sales Application."
: "Enabled Features in Sales Application."

, "Invoices Module"
: "Invoices Module"

, "Offers Module"
: "Offers Module"

, "Order Confirmations Module"
: "Order Confirmations Module"

, "Suppliers Module"
: "Suppliers Module"

, "Purchase Invoice Module"
: "Purchase Invoice Module"

, "You do not have admin rights on Sales"
: "You do not have admin rights on Sales"

, "Number duplicate"
: "Number duplicate"

, "The number you tried to use has been taken already. Please use another one leave the field blank to take the next free number."
: "The number you tried to use has been taken already. Please use another one leave the field blank to take the next free number."

, "Following Invoices Found"
: "Following Invoices Found"

, "There is an invoice for the same contract after this one. Please delete the following invoice(s) before deleting this one!"
: "There is an invoice for the same contract after this one. Please delete the following invoice(s) before deleting this one!"

, "Address as Billing Address in Use"
: "Address as Billing Address in Use"

, "The Address you tried to delete is used in one or more contract(s) as Billing Address. Please assign another Billing Address to these contracts or change this one and do not delete."
: "The Address you tried to delete is used in one or more contract(s) as Billing Address. Please assign another Billing Address to these contracts or change this one and do not delete."

, "Invoice is cleared already"
: "Invoice is cleared already"

, "The Invoice you tried to delete is cleared already, so deleting is not possible anymore!"
: "The Invoice you tried to delete is cleared already, so deleting is not possible anymore!"

, "No Right to alter the Number"
: "No Right to alter the Number"

, "You are not allowed to alter the number afterwards!"
: "You are not allowed to alter the number afterwards!"

, "The Invoice you tried to edit is cleared already, so no editing is possible anymore!"
: "The Invoice you tried to edit is cleared already, so no editing is possible anymore!"

, "Unknown Currency Code"
: "Unknown Currency Code"

, "The Currency Code you tried to use is not valid. Please use a valid Currency Code as defined in ISO 4217."
: "The Currency Code you tried to use is not valid. Please use a valid Currency Code as defined in ISO 4217."

, "Invoice Timesheet"
: "Invoice Timesheet"

, "CLEARED"
: "CLEARED"

, "INVOICE"
: "INVOICE"

, "GENDER_Cost Center"
: "GENDER_Cost Center"

, "Cost Center, Cost Centers"
: [
  "Cost Center"
 ,"Cost Centers"

]
, "GENDER_Offer"
: "GENDER_Offer"

, "GENDER_Invoice"
: "GENDER_Invoice"

, "Sales Tax"
: "Sales Tax"

, "Reversal Invoice"
: "Reversal Invoice"

, "Invoice Item"
: "Invoice Item"

, "Is active"
: "Is active"

, "GENDER_Contract"
: "GENDER_Contract"

, "Merge"
: "Merge"

, "Responsible"
: "Responsible"

, "Partner"
: "Partner"

, "Time Account"
: "Time Account"

, "GENDER_Customer)recordsName"
: "GENDER_Customer)recordsName"

, "GENDER_Order Confirmation"
: "GENDER_Order Confirmation"

, "GENDER_Supplier"
: "GENDER_Supplier"

, "GENDER_Division"
: "GENDER_Division"

, "Division, Divisions"
: [
  "Division"
 ,"Divisions"

]
, "Billing Interval"
: "Billing Interval"

, "Piece"
: "Piece"

, "GENDER_Address"
: "GENDER_Address"

, "Due at"
: "Due at"

, "Invoice Position, Invoice Positions"
: [
  "Invoice Position"
 ,"Invoice Positions"

]
, "Month"
: "Month"

, "Unit"
: "Unit"

, "The number you have tried to set is already in use!"
: "The number you have tried to set is already in use!"

, "My Products"
: "My Products"

, "Products created by me"
: "Products created by me"

, "My Contracts"
: "My Contracts"

, "Contracts created by myself"
: "Contracts created by myself"

, "All Customers"
: "All Customers"

, "All customer records"
: "All customer records"

, "All Offers"
: "All Offers"

, "All offer records"
: "All offer records"

, "Inactive Contracts"
: "Inactive Contracts"

, "Contracts that have already been terminated"
: "Contracts that have already been terminated"

, "Active Contracts"
: "Active Contracts"

, "Contracts that are still running"
: "Contracts that are still running"

, "All Suppliers"
: "All Suppliers"

, "All supllier records"
: "All supllier records"

, "All Purchase Imvoices"
: "All Purchase Imvoices"

, "All purchase invoices"
: "All purchase invoices"

, "All Products"
: "All Products"

, "All product records"
: "All product records"

, "All Contracts"
: "All Contracts"

, "All contract records"
: "All contract records"

, "All Invoices"
: "All Invoices"

, "All invoice records"
: "All invoice records"

, "All Cost Centers"
: "All Cost Centers"

, "All costcenter records"
: "All costcenter records"

, "All Divisions"
: "All Divisions"

, "All division records"
: "All division records"

, "All Order Confirmations"
: "All Order Confirmations"

, "All order confirmation records"
: "All order confirmation records"

, "You have to set a customer!"
: "You have to set a customer!"

, "Manage Products"
: "Manage Products"

, "Add, edit and delete products."
: "Add, edit and delete products."

, "Manage Contracts"
: "Manage Contracts"

, "Add, edit and delete contracts."
: "Add, edit and delete contracts."

, "Manage Cost Centers"
: "Manage Cost Centers"

, "Add, edit and delete cost centers."
: "Add, edit and delete cost centers."

, "Manage Customers"
: "Manage Customers"

, "Add, edit and delete customers."
: "Add, edit and delete customers."

, "Manage Suppliers"
: "Manage Suppliers"

, "Add, edit and delete suppliers."
: "Add, edit and delete suppliers."

, "manage invoices"
: "manage invoices"

, "Add, edit and delete invoices."
: "Add, edit and delete invoices."

, "Manage Divisions"
: "Manage Divisions"

, "Add, edit and delete divisions."
: "Add, edit and delete divisions."

, "Manage Order Confirmations"
: "Manage Order Confirmations"

, "Add, edit and delete order confirmations."
: "Add, edit and delete order confirmations."

, "Manage Offers"
: "Manage Offers"

, "Add, edit and delete offers."
: "Add, edit and delete offers."

, "Manage Purchase Invoices"
: "Manage Purchase Invoices"

, "Add, edit and delete purchase invoices."
: "Add, edit and delete purchase invoices."

, "Change number of an order confirmations"
: "Change number of an order confirmations"

, "Allow changing the number of an order confirmation during the update."
: "Allow changing the number of an order confirmation during the update."

, "Set number of invoices"
: "Set number of invoices"

, "Allow to set the number of an invoice."
: "Allow to set the number of an invoice."

, "Supplier"
: "Supplier"

, "Invoice"
: "Invoice"

, "Contract"
: "Contract"

, "Customer"
: "Customer"

, "Order Confirmation"
: "Order Confirmation"

, "Address"
: "Address"

, "Purchase Invoice"
: "Purchase Invoice"

, "Product"
: "Product"

, "Offer"
: "Offer"

, "Cost Center"
: "Cost Center"

, "Division"
: "Division"

, "Invoice Position"
: "Invoice Position"

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true; 
